function ww_Q = importQ(filename, dataLines)
%IMPORTFILE Import data from a text file
%  ww_Q = IMPORTFILE(FILENAME) reads data from text file FILENAME for
%  the default selection.  Returns the data as column vectors.
%
%  ww_Q = IMPORTFILE(FILE, DATALINES) reads data for the specified row
%  interval(s) of text file FILENAME. Specify DATALINES as a positive
%  scalar integer or a N-by-2 array of positive scalar integers for
%  dis-contiguous row intervals.
%
%  Example:
%  ww_Q = importfile("C:\Users\...\Anonymous_referee1\Weight_Q\ERL_wQ.txt", [1, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 19-Mar-2023 18:52:33

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [1, Inf];
end

%% Setup the Import Options and import the data
opts = delimitedTextImportOptions("NumVariables", 1);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = ",";

% Specify column names and types
opts.VariableNames = "ww_Q";
opts.VariableTypes = "double";

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";

% Import the data
tbl = readtable(filename, opts);

%% Convert to output type
ww_Q = tbl.ww_Q;
end